@@ -152,6 +152,11 @@ impl GlobalProfilerUi {
         let mut frame_view = self.global_frame_view.lock();
         self.profiler_ui.ui(ui, &mut frame_view);
     }
+
+    /// The frames we are looking at.
+    pub fn global_frame_view(&self) -> &GlobalFrameView {
+        &self.global_frame_view
+    }
 }
 
 // ----------------------------------------------------------------------------
@@ -508,7 +513,7 @@ impl ProfilerUi {
         }
 
         let desired_size = Vec2::new(
-            ui.available_size_before_wrap_finite().x,
+            ui.available_size_before_wrap().x,
             self.options.frame_list_height,
         );
         let (response, painter) = ui.allocate_painter(desired_size, Sense::click_and_drag());
